// Copyright 2022 Alibaba Group Holding Limited.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
#ifndef PYTHON_CLASS_H
#define PYTHON_CLASS_H

#include <python_class/pyjobject.h>
#include <python_class/pyjmethod.h>
#include <python_class/pyjmultimethod.h>
#include <python_class/pyjclass.h>
#include <python_class/pyjconstructor.h>
#include <python_class/pyjfield.h>
#include <python_class/pyjiterable.h>
#include <python_class/pyjiterator.h>
#include <python_class/pyjcollection.h>

#endif
